==========
Change Log
==========

-------------------
1.1.2_ - 2018-10-06
-------------------

Fixed bug in printAnalysis which caused it to fail on larger data sets.

-------------------
1.1.1_ - 2018-06-11
-------------------

Interactive analysis is now part of the main xenoGI script.

-------------------
1.1.0_ - 2018-06-03
-------------------

This is the first pypi release. In setting it up to be distributed as a package, we've also changed the user interface (see README.rst).

Hereafter, tagged releases correspond to pypi releases. The master branch will have the latest stable code. 

-------------------
1.0.0_ - 2017-11-14
-------------------

Initial release, corresponding to our article: "xenoGI: reconstructing the history of genomic island insertions in clades of closely related bacteria".

.. _1.1.2:  https://github.com/ecbush/xenoGI/compare/v1.1.1...v1.1.2
.. _1.1.1:  https://github.com/ecbush/xenoGI/compare/v1.1.0...v1.1.1
.. _1.1.0:  https://github.com/ecbush/xenoGI/compare/v1.0.0...v1.1.0
.. _1.0.0:  https://github.com/ecbush/xenoGI/releases/tag/v1.0.0
